from .CellAutomatBinary import CellAutomatBinary
from .CellAutomatRegression import CellAutomatRegression